# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [v1.1.7](https://github.com/jackton1/django-clone/releases/tag/v1.1.7) - 2020-09-07

<small>[Compare with v1.1.6](https://github.com/jackton1/django-clone/compare/v1.1.6...v1.1.7)</small>


## [v1.1.6](https://github.com/jackton1/django-clone/releases/tag/v1.1.6) - 2020-09-07

<small>[Compare with v1.1.5](https://github.com/jackton1/django-clone/compare/v1.1.5...v1.1.6)</small>


## [v1.1.5](https://github.com/jackton1/django-clone/releases/tag/v1.1.5) - 2020-09-07

<small>[Compare with v1.1.4](https://github.com/jackton1/django-clone/compare/v1.1.4...v1.1.5)</small>

### Fixed
- Fixed issues with sdist. ([ca59c86](https://github.com/jackton1/django-clone/commit/ca59c866ce2fb09822c3a6aa723bf1bf2dc18d9a) by Tonye Jack).


## [v1.1.4](https://github.com/jackton1/django-clone/releases/tag/v1.1.4) - 2020-09-07

<small>[Compare with v1.1.3](https://github.com/jackton1/django-clone/compare/v1.1.3...v1.1.4)</small>


## [v1.1.3](https://github.com/jackton1/django-clone/releases/tag/v1.1.3) - 2020-09-07

<small>[Compare with v1.1.2](https://github.com/jackton1/django-clone/compare/v1.1.2...v1.1.3)</small>

### Fixed
- Fixed manifest.in ([df2e40b](https://github.com/jackton1/django-clone/commit/df2e40b137cab9c8968d738fa2428e06bc5dbf44) by Tonye Jack).


## [v1.1.2](https://github.com/jackton1/django-clone/releases/tag/v1.1.2) - 2020-09-07

<small>[Compare with v1.1.1](https://github.com/jackton1/django-clone/compare/v1.1.1...v1.1.2)</small>

### Added
- Added missing changes. ([37de0a6](https://github.com/jackton1/django-clone/commit/37de0a6824933d1891f4b97d563ba9e17064690f) by Tonye Jack).


## [v1.1.1](https://github.com/jackton1/django-clone/releases/tag/v1.1.1) - 2020-09-07

<small>[Compare with v1.1.0](https://github.com/jackton1/django-clone/compare/v1.1.0...v1.1.1)</small>

### Added
- Added missing changes. ([64ec246](https://github.com/jackton1/django-clone/commit/64ec24661615d8d143081d2ad43ad4d9c97b1e1a) by Tonye Jack).

### Fixed
- Fixed makefile. ([9815226](https://github.com/jackton1/django-clone/commit/9815226ab63c363dfc09e450b93b917ced9828ff) by Tonye Jack).


## [v1.1.0](https://github.com/jackton1/django-clone/releases/tag/v1.1.0) - 2020-09-07

<small>[Compare with v1.0.0](https://github.com/jackton1/django-clone/compare/v1.0.0...v1.1.0)</small>


## [v1.0.0](https://github.com/jackton1/django-clone/releases/tag/v1.0.0) - 2020-09-05

<small>[Compare with v0.2.0](https://github.com/jackton1/django-clone/compare/v0.2.0...v1.0.0)</small>

### Added
- Add migrations ([1d9c68e](https://github.com/jackton1/django-clone/commit/1d9c68e84793f02415139ae7bac1f0c18da82a71) by Yuekui Li).

### Fixed
- Fix code style issues with black ([6249abe](https://github.com/jackton1/django-clone/commit/6249abe494cec23448d6fff09b7aa0eb2cf7978a) by Lint Action).
- Fixed test. ([240cc7c](https://github.com/jackton1/django-clone/commit/240cc7cb171d2d89c500e34c0511ab15a25d71f3) by Tonye Jack).
- Fixed github action. ([80bdd3e](https://github.com/jackton1/django-clone/commit/80bdd3ec6221b683957f4abf321130e599be174e) by Tonye Jack).
- Fixed flake8 error. ([7845ede](https://github.com/jackton1/django-clone/commit/7845ede0cbbf4a0d762f481dd184939096f8be17) by Tonye Jack).
- Fix invalid enum field value for unique_together fields ([1f83bf8](https://github.com/jackton1/django-clone/commit/1f83bf8472b47739c3a879a9b40199630178336a) by Yuekui Li).


## [v0.2.0](https://github.com/jackton1/django-clone/releases/tag/v0.2.0) - 2020-06-04

<small>[Compare with v0.1.6](https://github.com/jackton1/django-clone/compare/v0.1.6...v0.2.0)</small>

### Removed
- Removed unused code. ([6f3f515](https://github.com/jackton1/django-clone/commit/6f3f5158d8b21ab24d8743cc4b33823aa347aa44) by Tonye Jack).


## [v0.1.6](https://github.com/jackton1/django-clone/releases/tag/v0.1.6) - 2020-06-04

<small>[Compare with v0.1.5](https://github.com/jackton1/django-clone/compare/v0.1.5...v0.1.6)</small>

### Added
- Add renovate.json ([99d54b5](https://github.com/jackton1/django-clone/commit/99d54b5e5ff9eb3a759edf0d3610f1d587f69429) by Renovate Bot).

### Fixed
- Fixed unused imports. ([14e40e2](https://github.com/jackton1/django-clone/commit/14e40e2d42a9f016a9520f88e52f03ac40cd8768) by Tonye Jack).
- Fixed bug with index. ([dcd6256](https://github.com/jackton1/django-clone/commit/dcd625685b3b921d09526901a7458ac56389dda1) by Tonye Jack).
- Fixed lint errors. ([888d88d](https://github.com/jackton1/django-clone/commit/888d88d5605fb8ba7ebf19fd91d4cd1eca318e13) by Tonye Jack).
- Fixed test. ([ac7af5f](https://github.com/jackton1/django-clone/commit/ac7af5f973a54f2f4c59df403edf26dc38d51bd5) by Tonye Jack).

### Removed
- Remove the information for updating installed_apps ([4a4aa8c](https://github.com/jackton1/django-clone/commit/4a4aa8c0ef3a6943b8cfe43fae96c522d6126111) by Tonye Jack).


## [v0.1.5](https://github.com/jackton1/django-clone/releases/tag/v0.1.5) - 2020-05-12

<small>[Compare with v0.1.4](https://github.com/jackton1/django-clone/compare/v0.1.4...v0.1.5)</small>


## [v0.1.4](https://github.com/jackton1/django-clone/releases/tag/v0.1.4) - 2020-05-12

<small>[Compare with v0.1.3](https://github.com/jackton1/django-clone/compare/v0.1.3...v0.1.4)</small>

### Fixed
- Fixed typo. ([1613037](https://github.com/jackton1/django-clone/commit/16130379a65be64a5cc87ba716d300a3ac34a196) by Tonye Jack).
- Fixed formatting ([db2bfb2](https://github.com/jackton1/django-clone/commit/db2bfb27196b6187f2e07e3db85ac3129c70615f) by Tonye Jack).
- Fixed test errors ([f773001](https://github.com/jackton1/django-clone/commit/f773001fc8dc0f3811f74bd630b8c8e54e622992) by Tonye Jack).
- Fixed lint errors ([1a0900a](https://github.com/jackton1/django-clone/commit/1a0900ada94751908d671405c1c89e9c316926c8) by Tonye Jack).
- Fixed version. ([969b562](https://github.com/jackton1/django-clone/commit/969b562276ec908961c84296043ec9ba65a7f86e) by Tonye Jack).
- Fixed test. ([f66e745](https://github.com/jackton1/django-clone/commit/f66e74556c8924189f417a6195272b7267d92afb) by Tonye Jack).
- Fixed ordering. ([07d5f64](https://github.com/jackton1/django-clone/commit/07d5f64eb65fcf6962c238ebb26a2580770f4aa0) by Tonye Jack).

### Removed
- Remove unused line. ([7d6339a](https://github.com/jackton1/django-clone/commit/7d6339a8eba8e8d661b3004274a9fdfccf7afd55) by Tonye Jack).


## [v0.1.3](https://github.com/jackton1/django-clone/releases/tag/v0.1.3) - 2020-04-16

<small>[Compare with v0.1.2](https://github.com/jackton1/django-clone/compare/v0.1.2...v0.1.3)</small>

### Fixed
- Fixed typo ([e2f9643](https://github.com/jackton1/django-clone/commit/e2f9643ffd165adbe98c343293936b879061056d) by Tonye Jack).
- Fixed example documentation. ([b6ceae9](https://github.com/jackton1/django-clone/commit/b6ceae92bae52e7efa49789ffcd1cb7b749a8546) by Tonye Jack).
- Fixed lint errors. ([a72040d](https://github.com/jackton1/django-clone/commit/a72040d601a19e341d39381510c949d2f2316251) by Tonye Jack).
- Fix lint errors ([9dab0f7](https://github.com/jackton1/django-clone/commit/9dab0f7c5d7c6105d1552d3130050aa0889f94df) by Tonye Jack).
- Fixed invalid config. ([d33354b](https://github.com/jackton1/django-clone/commit/d33354ba8f83c5c694f52512db0575ce12d6fa19) by Tonye Jack).

### Removed
- Removed trailing whitespace. ([6933020](https://github.com/jackton1/django-clone/commit/6933020271094b054a9753e64a75d1064bb2fdb7) by Tonye Jack).
- Removed unused line ([0307889](https://github.com/jackton1/django-clone/commit/0307889c5550b098fa8cf553c91d0a5b3756b1ff) by Tonye Jack).


## [v0.1.2](https://github.com/jackton1/django-clone/releases/tag/v0.1.2) - 2019-12-03

<small>[Compare with v0.1.1](https://github.com/jackton1/django-clone/compare/v0.1.1...v0.1.2)</small>

### Fixed
- Fixed test. ([5b65a84](https://github.com/jackton1/django-clone/commit/5b65a842380d30ec84e4e6d3db882702385bfec8) by Tonye Jack).
- Fixed flake8 errors. ([ac0c27b](https://github.com/jackton1/django-clone/commit/ac0c27b2a93c10c29b3a32990752d3c544bf9619) by Tonye Jack).

### Removed
- Removed unused line. ([4e1d5d1](https://github.com/jackton1/django-clone/commit/4e1d5d144acccfb8a15a8551ce3902338387467b) by Tonye Jack).
- Remove tabs. ([f8c1a46](https://github.com/jackton1/django-clone/commit/f8c1a46e77c5c1ec42f4fc84af6872d2861a8a69) by Tonye Jack).
- Remove unused code. ([ecfa4b6](https://github.com/jackton1/django-clone/commit/ecfa4b623ed4456cff431095f4b62ec41badb829) by Tonye Jack).


## [v0.1.1](https://github.com/jackton1/django-clone/releases/tag/v0.1.1) - 2019-12-02

<small>[Compare with v0.1.0](https://github.com/jackton1/django-clone/compare/v0.1.0...v0.1.1)</small>

### Added
- Added pypi badge. ([e0a09e4](https://github.com/jackton1/django-clone/commit/e0a09e4dd084fd7ffe2c95a66aaa1a5b09762d78) by Tonye Jack).
- Added spec for cloning in parallel. ([bede5de](https://github.com/jackton1/django-clone/commit/bede5de00cd40a610c65d9d8ae19fa270cf8fc41) by Tonye Jack).

### Fixed
- Fixed indentation. ([75214a5](https://github.com/jackton1/django-clone/commit/75214a5b786a5322b8aa2af59fc95f6d0d10a78c) by Tonye Jack).
- Fixed flake8 error. ([b28fb8c](https://github.com/jackton1/django-clone/commit/b28fb8c5f67f1ef9b790fa7f0ac3e9b106544d6f) by Tonye Jack).
- Fixed example. ([1ad41d3](https://github.com/jackton1/django-clone/commit/1ad41d3f2866136a53d4fc0f91ded97ffe5f7f89) by Tonye Jack).
- Fixed test. ([ec39547](https://github.com/jackton1/django-clone/commit/ec395478f1ecfce4a1d1a0afbc8f0299d5f4c6dc) by Tonye Jack).
- Fixed lint errors and added support for running autopep8. ([4537a46](https://github.com/jackton1/django-clone/commit/4537a460de92d0ef34c875d37439f79c26a69d36) by Tonye Jack).
- Fix bug with cloning unique fields and added support for bulk_clone. ([70e76a8](https://github.com/jackton1/django-clone/commit/70e76a81e6497ef52a2d525bc4a5e6a27d5b0e75) by Tonye Jack).
- Fix typo clonemodeladmin -> clonemodeladmin ([b8a29c2](https://github.com/jackton1/django-clone/commit/b8a29c240aba7f7736ef297a69f54eb0a399d1ad) by SebastianKapunkt).

### Removed
- Remove .extend. ([3e31e86](https://github.com/jackton1/django-clone/commit/3e31e86ab49d834cc2aad89760fa2a25eff687df) by Tonye Jack).


## [v0.1.0](https://github.com/jackton1/django-clone/releases/tag/v0.1.0) - 2019-11-23

<small>[Compare with v0.0.11](https://github.com/jackton1/django-clone/compare/v0.0.11...v0.1.0)</small>


## [v0.0.11](https://github.com/jackton1/django-clone/releases/tag/v0.0.11) - 2019-11-23

<small>[Compare with v0.0.10](https://github.com/jackton1/django-clone/compare/v0.0.10...v0.0.11)</small>

### Fixed
- Fixed lint errors. ([5b9ceae](https://github.com/jackton1/django-clone/commit/5b9ceae369da2322ee6cdbed785b0fab74275aad) by Tonye Jack).
- Fixed indentation. ([18e382d](https://github.com/jackton1/django-clone/commit/18e382d9b23872a725c97ab44333e4a354d2c123) by Tonye Jack).
- Fixed duplicate context ([be24df3](https://github.com/jackton1/django-clone/commit/be24df310abd82f4c7d716b18da82c376246578f) by Tonye Jack).
- Fixed yaml lint errors. ([ec949cb](https://github.com/jackton1/django-clone/commit/ec949cb75bcab1783e417e19ea3c04efa86b9658) by Tonye Jack).
- Fixed flake8 errors. ([133d404](https://github.com/jackton1/django-clone/commit/133d404acf49bf134f382bd98e06395fde7abe1f) by Tonye Jack).

### Removed
- Removed unused file. ([bc869a7](https://github.com/jackton1/django-clone/commit/bc869a78428ef27f8af0f2abdb11e56331faa4c3) by Tonye Jack).
- Removed node_modules. ([ae75573](https://github.com/jackton1/django-clone/commit/ae75573519bc6223ccdbe905ed49f4c3f050da18) by Tonye Jack).
- Removed empty config ([b779051](https://github.com/jackton1/django-clone/commit/b77905110a26ba96d22967cdb761e552dd0d8c6a) by Tonye Jack).


## [v0.0.10](https://github.com/jackton1/django-clone/releases/tag/v0.0.10) - 2019-11-12

<small>[Compare with v0.0.9](https://github.com/jackton1/django-clone/compare/v0.0.9...v0.0.10)</small>

### Fixed
- Fixed manage.py. ([eaa73f6](https://github.com/jackton1/django-clone/commit/eaa73f6687b4bf586cd4c6468819a615aea76d37) by Tonye Jack).
- Fixed pyenv. ([66aabd5](https://github.com/jackton1/django-clone/commit/66aabd5536d6b924d56b4a04180c460fdc399449) by Tonye Jack).
- Fixed tox. ([82afdde](https://github.com/jackton1/django-clone/commit/82afdde7929d85b55bec6e4ad8784e268564bbee) by Tonye Jack).
- Fixed python27. ([20b3c55](https://github.com/jackton1/django-clone/commit/20b3c55ecaa376d8069134427b39ce857c218931) by Tonye Jack).

### Removed
- Removed bumpversion==0.5.3. ([60a18e5](https://github.com/jackton1/django-clone/commit/60a18e57e7e4b98335cc7c612c25e77f8a5b4564) by Tonye Jack).


## [v0.0.9](https://github.com/jackton1/django-clone/releases/tag/v0.0.9) - 2019-11-10

<small>[Compare with v0.0.8](https://github.com/jackton1/django-clone/compare/v0.0.8...v0.0.9)</small>


## [v0.0.8](https://github.com/jackton1/django-clone/releases/tag/v0.0.8) - 2019-11-10

<small>[Compare with v0.0.7](https://github.com/jackton1/django-clone/compare/v0.0.7...v0.0.8)</small>


## [v0.0.7](https://github.com/jackton1/django-clone/releases/tag/v0.0.7) - 2019-11-10

<small>[Compare with v0.0.6](https://github.com/jackton1/django-clone/compare/v0.0.6...v0.0.7)</small>


## [v0.0.6](https://github.com/jackton1/django-clone/releases/tag/v0.0.6) - 2019-11-10

<small>[Compare with v0.0.5](https://github.com/jackton1/django-clone/compare/v0.0.5...v0.0.6)</small>

### Added
- Added twine to deploy requirements ([59eba81](https://github.com/jackton1/django-clone/commit/59eba81e23cfb07687ae2c1b01ce82573597f61a) by Tonye Jack).


## [v0.0.5](https://github.com/jackton1/django-clone/releases/tag/v0.0.5) - 2019-11-10

<small>[Compare with v0.0.3](https://github.com/jackton1/django-clone/compare/v0.0.3...v0.0.5)</small>

### Added
- Added the changelog.md ([3e6aeb2](https://github.com/jackton1/django-clone/commit/3e6aeb2307fe5a29b9e68fd1acac1ae5e3cfe974) by Tonye Jack).


## [v0.0.3](https://github.com/jackton1/django-clone/releases/tag/v0.0.3) - 2019-11-10

<small>[Compare with v0.0.1](https://github.com/jackton1/django-clone/compare/v0.0.1...v0.0.3)</small>

### Added
- Add class variable use_unique_duplicate_suffix ([fd207c4](https://github.com/jackton1/django-clone/commit/fd207c41398a469ebca01bbe7ad7c0284a54d218) by Andres Portillo).
- Added new line at the end of the file. ([b5b68fc](https://github.com/jackton1/django-clone/commit/b5b68fc139e5c708c5f370fc4b3256d31d1daefc) by Tonye Jack).
- Added new line. ([4327dab](https://github.com/jackton1/django-clone/commit/4327dab28b06a0efec071eb4822bc916945399dc) by Tonye Jack).
- Added create_copy_of_instance utility. ([ab41b02](https://github.com/jackton1/django-clone/commit/ab41b02f1b52cf8f4ca6b7452085f66e69f25bb7) by Tonye Jack).
- Add django-admin clonablemodeladmin ([147c56f](https://github.com/jackton1/django-clone/commit/147c56fa59f770278050eeecf0868a611a15e060) by Sebastian Kindt).

### Changed
- Change comparison to check for any truthy value ([6d11bd1](https://github.com/jackton1/django-clone/commit/6d11bd1ae43d395ec08e6764cdf7cff597b79f54) by Andres Portillo).
- Changed docker image. ([9644e73](https://github.com/jackton1/django-clone/commit/9644e73e4682904df818e678484971edb5118990) by Tonye Jack).

### Fixed
- Fix admin url regex ([e806e97](https://github.com/jackton1/django-clone/commit/e806e97bcbaec9f3030db97f6afce4ff9700619e) by Tonye Jack).
- Fixed test. ([d7cc014](https://github.com/jackton1/django-clone/commit/d7cc014c7b7547863865bdb98b1e8c7d2b32d75d) by Tonye Jack).
- Fix clone of one to many and many to one ([78a506b](https://github.com/jackton1/django-clone/commit/78a506b6caff3a7715f35a617f96c56bf2087028) by Sebastian Kindt).
- Fixed install command. ([1ea325c](https://github.com/jackton1/django-clone/commit/1ea325c2981a22f62b2c52011a3c77d82c2c77c5) by Tonye Jack).
- Fixed virtualenv. ([eab8da9](https://github.com/jackton1/django-clone/commit/eab8da905bd110e7d8bffe4b1bb680c45caa8d75) by Tonye Jack).

### Removed
- Removed extra spaces. ([28f327f](https://github.com/jackton1/django-clone/commit/28f327fbdf129e5477dc200f8af822a10a4867a0) by Tonye Jack).
- Remove redundant one to one clone. ([d1a56bd](https://github.com/jackton1/django-clone/commit/d1a56bdc1c7f000b5729b7c13324077e1b2a7267) by Tonye Jack).
- Removed unused code. ([6216032](https://github.com/jackton1/django-clone/commit/6216032d67534f0ab35da8efb574a6c1aebcf838) by Tonye Jack).


## [v0.0.1](https://github.com/jackton1/django-clone/releases/tag/v0.0.1) - 2019-04-06

<small>[Compare with first commit](https://github.com/jackton1/django-clone/compare/7b01ca1df72d4ac2a691257807cf9eab426332ae...v0.0.1)</small>

### Added
- Added pypi deployment setup. ([96816e6](https://github.com/jackton1/django-clone/commit/96816e66ca00d6146860cb96e64047d8f5add6d8) by Tonye Jack).
- Added circleci config. ([af22fc8](https://github.com/jackton1/django-clone/commit/af22fc8c00fdb17f12d83140c35a50cd8c678ba9) by Tonye Jack).
- Added base class setup. ([7b01ca1](https://github.com/jackton1/django-clone/commit/7b01ca1df72d4ac2a691257807cf9eab426332ae) by Tonye Jack).

### Fixed
- Fixed typo. ([1cfe037](https://github.com/jackton1/django-clone/commit/1cfe037e50c8fca6c31a31ecf4b36b7c88c39fbe) by Tonye Jack).


